@@ -1,15 +1,14 @@
-package UNIVERSAL::isa;
-# git description: 1.20140824-2-g1cfb04c
-$UNIVERSAL::isa::VERSION = '1.20140927';
-# ABSTRACT: Attempt to recover from people calling UNIVERSAL::isa as a function
-
 use strict;
 use warnings;
-use 5.6.2;
+package UNIVERSAL::isa; # git description: 1.20140927-9-g397ee12
+# ABSTRACT: Attempt to recover from people calling UNIVERSAL::isa as a function
 
-use UNIVERSAL ();
-use Scalar::Util 'blessed';
-use warnings::register;
+our $VERSION = '1.20150614';
+
+use 5.006002;
+
+use Scalar::Util ();
+use warnings::register; # creates a warnings category for this module
 
 my ( $orig, $verbose_warning );
 
@@ -42,7 +41,7 @@ sub _invocant_type
 {
     my $invocant = shift;
     return \&_nonsense unless defined($invocant);
-    return \&_object_or_class if blessed($invocant);
+    return \&_object_or_class if Scalar::Util::blessed($invocant);
     return \&_reference       if ref($invocant);
     return \&_nonsense unless $invocant;
     return \&_object_or_class;
@@ -112,7 +111,7 @@ UNIVERSAL::isa - Attempt to recover from people calling UNIVERSAL::isa as a func
 
 =head1 VERSION
 
-version 1.20140927
+version 1.20150614
 
 =head1 SYNOPSIS
 
@@ -193,13 +192,6 @@ chromatic <chromatic@wgz.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2011 by chromatic@wgz.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Karen Etheridge Ricardo Signes
@@ -216,4 +208,11 @@ Ricardo Signes <rjbs@cpan.org>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by chromatic@wgz.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
